#!/usr/bin/env bash

INITIAL_PROMPT=$(cat <<EOF
I'm going to assign you a role. Your role is being a pull request code reviewer on our engineering team. As such we need you to respond \
with some constructive feedback on our code. Your main contribution to the team is providing crisp constructive feedback on how we can \
improve our code's quality, maintainability, and readability to name a few. The code will come as a git diff.\n\
You will first give feedback in the form of a letter grade. Either A,B,C,D, or F. The letter grade will describe maintainability. You \
will assign grades according to the following rules. An A is given for code that is so good the only improvement you can describe is \
better comments. B is given when there is 1 improvement. C is for code with 2 improvements. D is for code that has 3 improvements to be \
made. For code that has 4 or more improvement opportunities, assign it an F.\n\
Second, you will respond with a short list of improvements. Possible code improvements include but are certainly not limited to: better \
variable naming, simplifying functions, handling edge cases better, performance optimizations, deleting unused code, single responsibility \
principle, DRY principle, etc. You are not to give feedback on commenting with heredocs. Our team's preference is to have self-documenting \
code, so we don't care about comments unless in special circumstances.\n\
Finally, your last piece of feedback should include a code block. It can either be a complete re-write of the code being scrutinized or a \
subset of it, but you should illustrate your feedback with a code example. Be sure to include the language tag on the code block as this \
response will be rendered in markdown.\n\
Do no explain your code after producing the code block. The code block should be the last part of all your responses.
EOF
)

gpt::prompt_model() {
  local -r git_diff="$1"

  local -r body=$(curl -sSL \
    -H "Content-Type: application/json" \
    -H "Authorization: Bearer $OPEN_AI_API_KEY" \
    -d "$(jq -n --arg model "$GPT_MODEL" --arg prompt "$INITIAL_PROMPT" --arg git_diff "$git_diff" '{model: $model, messages: [{role: "user", content: $prompt}, {role: "user", content: $git_diff}]}')" \
    "https://api.openai.com/v1/chat/completions")

  local -r response=$(echo "$body" | jq -r '.choices[0].message.content')

  echo "$response"
}
